Robertspark's CNC Setup

More
4 years 8 months ago #234241 by robertspark
Replied by robertspark on topic Robertspark's CNC Setup
Couple of things I am looking at integrating / have integrated and need to provide a quick link on to find in the future:

forum.linuxcnc.org/49-basic-configuratio...obe?start=550#232195

forum.linuxcnc.org/38-general-linuxcnc-q...xcnc?start=10#213111

Please Log in or Create an account to join the conversation.

More
4 years 8 months ago #234396 by robertspark
Replied by robertspark on topic Robertspark's CNC Setup
TIPS:
I thought I'd post a few shortcut tips that I've learnt using linux, stuff that may be obvious to some who just use linux or have been using it for years.  But for me, a native button clicking windows user who although used dos, still likes a gui the terminal has taken a bit of getting used to:

I will try to add a few more tips to this list as I remember or use them.

Use the TAB button / key
when typing out something such as directory change, or to run a file or open a deb file, use the TAB key for linux to autocomplete the text.  It also avoids typos on long complex file names....
eg:
cd lin <TAB> will complete the line as
cd linuxcnc-dev if you have a linuxcnc-dev file that is
likewise
cd Dow<TAB> will complete the line as
cd Downloads
you can also do multiple TABs on a line, such as:
cd lin<TAB> ..... which becomes
cd linuxcnc-dev, then type /deb<TAB> and it will complete the line as
cd linuxcnc-dev/debian
likewise if you are installing a debian (*.deb) file
dpkg -i she<TAB>
will complete the line as
dpkg -i sheetcam_v1.2xyzabx.deb
you can also use it to run files too.... if in doubt, just press tab and it may complete the line for you from the current directory or the directory you are navigating to such as 
sudo geany etc/net<TAB>/int<TAB> will open the network interfaces file.

sudo Folder Access / File Edit (graphically)
being a windows guy, I like to sometimes use the graphical folder view to navigate my way to edit files (such as the user.config file and the network/interfaces file and other stuff that requires sudo (super user) privileges, hence I open a terminal and run
Code:
sudo Thunar
this allows the Folder viewer GUI (Thunar) to open with sudo privileges and then you can just navigate to the file and double click on it to open it in Geany again with super user privileges to edit and save it accordingly.

terminal commands:
clear - clear terminal screen
cd - change directory (eg. cd linuxcnc-dev will move up to the linuxcnc-dev directory (if there is such a folder in the current directory)
cd OR cd ~ - changes to the home directory 
cd .. - step back a directory level (e.g. if the current directory level is /linuxcnc-dev/debian, and you type cd .. it will move 1 level back to /linuxcnc-
cd / - changes to the root directory
ls - list contents of current directory
ls *.deb - list all deb extension files in the current directory (can be used with *.sh or whatever extension you require, can change it to ls sh* which will list all files beginning with "sh" in the current directory).
uname -a - displays the linux kernel and release and architecture information within the terminal (to ensure you are running an "RT" (real time) patched kernel + it's version.  can use uname -v for just the kernel version.
ip link show - shows all network card addresses and names (ethX OR enpX for ethernet cards and wlanX for wifi cards)
/sbin/ifconfig -a - displays any network errors or collisions etc, useful to check after a long uptime / run to see if you have potential network issues.
lscpu - list cpu information, useful for isolating cpu's + checking how many cores you have listed and if hyperthreading is turned on / off etc.
lscpu | egrep 'Model name|Socket|Thread|NUMA|CPU\(s\)' - list cpu info in a bit more concise format than just an lscpu info dump.
nproc - lists the number of processes that can be run simultaneously (eg, a dual core machine with hyperthreading can run 4 threads at once, see make below).
make -j4 - when using the make / build command the "-j4" switch tells the make command to run 4 jobs at once, this normally corresponds to your number of processes that are available.
make -j$(nproc) - alternative to the above make -j4, if you are unsure of your number of parallel processes that are able to run at once, will always use the maximum number, and complete the make process as quick as possible (useful for building linuxcnc as a RIP making *.deb files on the machine).
find - very useful (and quick) way to find files on linux, there are a few switches for finding all specific files and folders in specific locations.
find  / -type d -name "apt" -ls - find all directories with the name apt (case sensitive).
find  / -type d -iname "apt" -ls - find all directories with the name apt or APT or Apt or aPt or apT or APt or aPT or ApT (case insensitive)
find / -name '*.py' - find all files OR folders with the extension .py (case sensitive).  can use the wild card as the extension if you know the first part of the file / folder name.
find / -type f -name '*.py' - find only files with the extension .py (case sensitive), could use -iname to make case insensitive, could obviously change to *.dxf or anything that you've lost.  find is very powerful on linux, but the switches can confusing to remember (for me) unless used often.


 
The following user(s) said Thank You: phillc54, tommylight, tripwire

Please Log in or Create an account to join the conversation.

More
4 years 8 months ago #235264 by robertspark
Replied by robertspark on topic Robertspark's CNC Setup
I'm going to do a tidy up of some of the above (but this forum editor is a PIA to re-edit posts):

I've been dabbling (again) with Debian Bullseye, as I thought I'd give QtPyVCP a go both from the perspective of using Probe Basic for Mill and Lathe and getting stop using Gmoccopy. I though I'd also give creating simple screensets a go for my 3/4 axis mill + router + lathe as I don't have an ATC but I do have a 40 position multifix tool post for the lathe with a lot of tool holders all on a rack with numbers.

Enough waffle:

Download Debian Bullseye from the Debian repository via ISO
www.debian.org/download

I tend to use the non-free version amd64 as I have intel network cards and the non-free version will provide the firmware "out of the box" at install time, so I download from here:
cdimage.debian.org/cdimage/unofficial/no...urrent/amd64/iso-cd/

I use etcher (or if on linux dd) the iso onto usb stick and then install accordingly.

once the install is complete,

I will add my user account to the sudo (super user) group by logging on to the root account and adding myself to the sudo users group (it makes life easier to install stuff + its just a cnc machine and I'm not fussed if it was ever hacked... it does not run unless I'm present or nearby).
type the following into the terminal:
Code:
su
enter the root / su / super user password
type:
Code:
sudo usermod -a -G sudo username
.... change "username" to YOUR login name obviously!

being linux.... if it worked you won't get a complaint or response... if not it will pop up with a message.

you will need to log off and log back on in order for the change to take place to the user account.

I will run the following scripts to install the programmes I use in my setup:
Code:
sudo apt update
Code:
sudo apt upgrade -y
Code:
sudo apt install -y git geany grub-customizer git ethtool curl dpkg-dev

install the RT patched kernel:
Code:
sudo apt install -y linux-image-rt-amd64 linux-headers-rt-amd64

I normally start Thunar with super user privilages
Code:
sudo Thunar

and then I navigate to etc/network/ and open the interfaces file and set up my network settings: {THEY WON'T WORK FOR YOU!}
Code:
# This file describes the network interfaces available on your system # and how to activate them. For more information, see interfaces(5). source /etc/network/interfaces.d/* # The loopback network interface auto lo iface lo inet loopback auto enp2s0 iface enp2s0 inet static address 10.10.10.1/24 up sleep 3 post-up ethtool -C enp2s0 rx-usecs 0 auto enp3s0 iface enp3s0 inet static address 172.16.0.1/24 up sleep 3 post-up ethtool -C enp3s0 rx-usecs 0

next navigate to: /etc/lightdm/ and open lightdm.conf
scroll down to around line 126 and remove the # from the two following lines + add YOUR login name:

#autologin-user=
#autologin-user-timeout=0

So that linux will automatically log in.

I normally navigate to the Power Manager under the Applications >> Settings menu and change the settings so that the screen does not start the screensaver / turn off the monitor or stop the monitor turning off, screensaver starting or more importantly, linux logging off and requiring a login.... (could be frustrating if you need to stop something in a hurry without using the estop mushroom button)

I will normally navigate to Grub-Customiser (located under Applications >> System)
and on the General tab change the start delay from 5 seconds to 1 second, and change the kernel parameters to:
Code:
quiet splash isolcpus=1,3
NOTE:: isolcups may NOT work for you + it depends upon how many CPUs and cores you have, test your own latency.... it works for my bios settings.

I normally install all my free CAD software (+ sheetcam and lightburn)
Code:
sudo apt install -y inkscape gimp librecad freecad

www.sheetcam.com/downloads
lightburnsoftware.com/pages/trial-version-try-before-you-buy

install sheetcam *.deb via:
[sudo]sudo sudo dpkg -i Sheet*.deb[/code]
or press the <TAB> key after typing "She" to autocomplete
Sheetcam {current release} requires a couple of dependencies....
Code:
sudo apt install -y libncurses5 libinfo5
version 6 of libncurses and libinfo is already installed.... you could unpack and repack the *.deb and change the dependencies (and hope they work with the newer versions.... of just install version 5 of the two above dependencies...

There is another dependency which is missing which is libreadline7..... again version 8 is installed within Debian Bullseye... and version 7 is not available from the repositories ..... however it can be downloaded from an older debian repository as a *.deb file and installed:
packages.debian.org/buster/amd64/libreadline7/download
then run {from the Downloads directory}:
Code:
sudo dpkg -i lib+<TAB>
and then try to reinstall Sheetcam via:
[sudo]sudo sudo dpkg -i Sheet*.deb[/code]
and it should run just fine (it does on my debian Bullseye install now!).

Oh the joys of linux and dependencies and version compatibility!


for lightburn *.run file you may need to make it executable via:
Code:
chmod 774 Lig+<TAB>
and then you can install it via
Code:
./Lig+<TAB>

OK now the LinuxCNC stuff.....

Install some more dependencies for LinuxCNC + QtPyVCP using the following (kindly taken from the QtPyVCP website):
Code:
sudo apt install -y geany git debhelper dh-python libudev-dev tcl8.6-dev tk8.6-dev bwidget tclx libeditreadline-dev asciidoc dblatex docbook-xsl dvipng ghostscript graphviz groff imagemagick inkscape python3-lxml source-highlight w3c-linkchecker xsltproc texlive-extra-utils texlive-font-utils texlive-fonts-recommended texlive-lang-cyrillic texlive-lang-french texlive-lang-german texlive-lang-polish texlive-lang-spanish texlive-latex-recommended asciidoc-dblatex python3-dev python3-tk libxmu-dev libglu1-mesa-dev libgl1-mesa-dev libgtk2.0-dev libgtk-3-dev gettext intltool autoconf libboost-python-dev libmodbus-dev libusb-1.0-0-dev psmisc yapps2 libepoxy-dev python3-xlib python3-pyqt5 python3-dbus.mainloop.pyqt5 python3-pyqt5.qtopengl python3-pyqt5.qsci python3-pyqt5.qtmultimedia python3-pyqt5.qtquick qml-module-qtquick-controls gstreamer1.0-plugins-bad libqt5multimedia5-plugins pyqt5-dev-tools python3-dev python3-setuptools python3-wheel python3-pip python3-yapps dpkg-dev python3-serial libtk-img qttools5-dev qttools5-dev-tools python3-wheel espeak espeak-data espeak-ng freeglut3 gdal-data gstreamer1.0-tools libaec0 libarmadillo10 libarpack2 libcfitsio9 libcharls2 libdap27 libdapclient6v5 libepsilon1 libespeak1 libfreexl1 libfyba0 libgdal28 libgdcm3.0 libgeos-3.9.0 libgeos-c1v5 libgeotiff5 libgif7 libglew2.1 libgtksourceview-3.0-dev libhdf4-0-alt libhdf5-103-1 libhdf5-hl-100 libimagequant0 libkmlbase1 libkmldom1 libkmlengine1 liblept5 libmariadb3 libminizip1 libnetcdf18 libodbc1 libogdi4.1 libopencv-calib3d4.5 libopencv-contrib4.5 libopencv-core4.5 libopencv-dnn4.5 libopencv-features2d4.5 libopencv-flann4.5 libopencv-highgui4.5 libopencv-imgcodecs4.5 libopencv-imgproc4.5 libopencv-ml4.5 libopencv-objdetect4.5 libopencv-photo4.5 libopencv-shape4.5 libopencv-stitching4.5 libopencv-video4.5 libopencv-videoio4.5 libportaudio2 libpq5 libproj19 libprotobuf23 libqhull8.0 librttopo1 libsocket++1 libspatialite7 libsuperlu5 libsz2 libtbb2 libtesseract4 liburiparser1 libxerces-c3.2 libxml2-dev mariadb-common mesa-utils mysql-common odbcinst odbcinst1debian2 proj-bin proj-data python3-configobj python3-espeak python3-gi-cairo python3-olefile python3-opencv python3-opengl python3-pil python3-pil.imagetk python3-pyqt5.qtsvg python3-pyqt5.qtwebkit tcl-tclreadline geotiff-bin gdal-bin glew-utils libgtksourceview-3.0-doc libhdf4-doc libhdf4-alt-dev hdf4-tools odbc-postgresql tdsodbc ogdi-bin python-configobj-doc libgle3 python-pil-doc python3-pil-dbg python3-pil.imagetk-dbg python3-sqlalchemy netcat

Download Master / 2.9 from linuxcnc repository git and build *.debs for install....
Code:
cd ~ mkdir dev cd dev mkdir linuxcnc cd linuxcnc git clone git://github.com/linuxcnc/linuxcnc.git rip

make and build the *.debs {without documentation (it's all on line anyway on the linuxCNC website) + its quicker}
also note the -j4 switch for dpkg-buildpackage which will use 4x threads / simultaneous operations for a 4 core machine... adjust to your machine setup as it will be much quicker than without the switch if you have multiple cores.
Code:
cd ~/dev/linuxcnc/rip/debian ./configure no-docs uspace cd .. dpkg-buildpackage -j4 -b -uc

Install the linuxCNC *.deb
Code:
cd ~/dev/linuxcnc sudo dpkg -i linuxcnc-uspace_2.9.0~pre0_amd64.deb

Install QtPyVCP:
Code:
cd ~/dev git clone https://github.com/kcjengr/qtpyvcp cd qtpyvcp python3 -m pip install --editable . cp scripts/.xsessionrc ~/

Don't forget or miss those damn dots ( . )!!!! or it will fling you an error!

You can test QtPyVCP:
Code:
qtpyvcp -h qtpyvcp -i

And then setup QT Designer:
Code:
cd ~/dev/qtpyvcp/pyqt5designer/Qt5.15.2-64bit/python3.9/ sudo ./install.sh

Setup / install the QtPyVCP Sims:
Code:
cp -r ~/dev/qtpyvcp/linuxcnc ~/

To setup / install Probe Basic for Python 3!!:
Code:
cd ~/dev git clone -b python3 https://github.com/kcjengr/probe_basic.git [code] To setup / install probe basic (mill) + probe basic lathe: [code] cd probe_basic qcompile . python3 -m pip install -e . cd cp -r ~/probe_basic/probe_basic/fonts/ ~/.local/share/ cp -r ~/probe_basic/config/probe_basic/ ~/linuxcnc/configs/ cp -r ~/probe_basic/config/probe_basic_lathe/ ~/linuxcnc/configs/

Again don't miss those damn dots....

To install the QtPyVCP Conversational G-code Widgets:
Code:
cd ~/dev git clone -b python3 https://github.com/kcjengr/qtpyvcp.conversational-gcode.git cd ~dev/qtpyvcp.conversational-gcode python3 -m pip install .

To Edit Probe_Basic (mill) screenset:
Code:
editvcp probe_basic

To Edit Probe_Basic_Lathe screenset:
Code:
editvcp probe_basic_lathe

To download the QtPyVCP Template:
github.com/kcjengr/vcp-template
Code:
cd ~/dev git clone https://github.com/kcjengr/vcp-template.git

install:
Code:
python3 -m pip install -e .

edit it with:
Code:
editvcp myvcp
Note: you will need to name it prior to this using:
Code:
cd ~/dev/vcp-template ./copy.sh

To create the Tutorial, run:
Code:
cd ~/dev/vcp-template ./tutorial.sh

update any of the folders using:
Code:
git pull

you can also create a bash script to update and build etc by creating a new file and saving it as a *.sh, and running chmod 774 *.sh to maake it executable ..... add within the first line of the file:
Code:
#!/bin/bash
then run with ./xyz.sh with whatever you called the script (very helpful to run and leave to sort its self out)...

Please Log in or Create an account to join the conversation.

More
4 years 8 months ago #235296 by jkkicks
Replied by jkkicks on topic Robertspark's CNC Setup
This is awesome, almost got it working first try!

Probe basic lathe works right out of the box, editvcp and qtpyvcp are all installed and working properly with no error codes. One thing I did notice though is that in the linuxcnc configuration selector there is no folder for probe basic, but if i choose sim.qtpyvcp, XYZ i can launch right into the probe basic lathe program.

thats where the good news ends though. When launching the xyz config and selecting probe_basic i still get an error code and a crash... Heres the error message:
{
Traceback (most recent call last):
  File "/home/cnc/.local/bin/qtpyvcp", line 33, in <module>
    sys.exit(load_entry_point('qtpyvcp===python3-master-174.g2c249709', 'console_scripts', 'qtpyvcp')())
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/__init__.py", line 74, in main
    run(opts, None)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/__init__.py", line 102, in run
    load_vcp(opts)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/launcher.py", line 131, in load_vcp
    if _load_vcp_from_entry_point(vcp, opts):
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/launcher.py", line 181, in _load_vcp_from_entry_point
    vcp.main(opts)
  File "/home/cnc/dev/probe_basic/probe_basic/__init__.py", line 20, in main
    qtpyvcp.run_vcp(opts, VCP_CONFIG_FILE)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/__init__.py", line 27, in run_vcp
    run(*args, **kwargs)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/__init__.py", line 129, in run
    launch_application(opts, config)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/launcher.py", line 78, in launch_application
    loadWindows(config)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/launcher.py", line 228, in loadWindows
    window = _initialize_object_from_dict(window_dict)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/app/launcher.py", line 208, in _initialize_object_from_dict
    return obj(*args, **kwargs)
  File "/home/cnc/dev/probe_basic/probe_basic/probe_basic.py", line 24, in __init__
    super(ProbeBasic, self).__init__(*args, **kwargs)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/widgets/form_widgets/main_window.py", line 43, in __init__
    self.loadUi(ui_file)
  File "/home/cnc/.local/lib/python3.9/site-packages/qtpyvcp/widgets/form_widgets/main_window.py", line 102, in loadUi
    uic.loadUi(ui_file, self)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/__init__.py", line 238, in loadUi
    return DynamicUILoader(package).loadUi(uifile, baseinstance, resource_suffix)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/Loader/loader.py", line 66, in loadUi
    return self.parse(filename, resource_suffix)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 1037, in parse
    actor(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 828, in createUserInterface
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 273, in createWidget
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 503, in createLayout
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 546, in handleItem
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 503, in createLayout
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 546, in handleItem
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 503, in createLayout
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 546, in handleItem
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 273, in createWidget
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 273, in createWidget
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 503, in createLayout
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 546, in handleItem
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 273, in createWidget
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 273, in createWidget
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 503, in createLayout
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 546, in handleItem
    self.traverseWidgetTree(elem)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 806, in traverseWidgetTree
    handler(self, child)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 264, in createWidget
    self.stack.push(self.setupObject(widget_class, parent, elem))
  File "/usr/lib/python3/dist-packages/PyQt5/uic/uiparser.py", line 228, in setupObject
    obj = self.factory.createQObject(clsname, name, args, is_attribute)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/objcreator.py", line 100, in createQObject
    factory = self.findQObjectType(classname)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/objcreator.py", line 125, in findQObjectType
    w = module.search(classname)
  File "/usr/lib/python3/dist-packages/PyQt5/uic/Loader/qobjectcreator.py", line 113, in search
    module = __import__(mname, {}, {}, (cls,))
ModuleNotFoundError: No module named 'qtpyvcp_conversational_gcode'
}

 

what do i do... im laughing and crying all at once

Please Log in or Create an account to join the conversation.

More
4 years 5 months ago - 4 years 5 months ago #243886 by robertspark
Replied by robertspark on topic Robertspark's CNC Setup
cdimage.debian.org/cdimage/unofficial/no....0-amd64-netinst.iso
Code:
sudo apt install -y git geany grub-customizer git ethtool curl dpkg-dev linux-image-rt-amd64 linux-headers-rt-amd64 flameshot
Code:
sudo apt install -y debhelper dh-python libudev-dev autoconf bwidget gettext intltool libboost-python-dev libepoxy-dev libgl1-mesa-dev libglu1-mesa-dev libgtk2.0-dev libgtk-3-dev libmodbus-dev libusb-1.0-0-dev libxmu-dev netcat psmisc python3-dev python3-tk python3-xlib tcl8.6-dev tclx8.4 tk8.6-dev yapps2 asciidoc dblatex docbook-xsl dvipng graphviz groff imagemagick inkscape python3-lxml source-highlight w3c-linkchecker xsltproc texlive-extra-utils texlive-font-utils texlive-fonts-recommended texlive-lang-cyrillic texlive-lang-french texlive-lang-german texlive-lang-polish texlive-lang-spanish texlive-latex-recommended asciidoc-dblatex texlive-xetex libreadline-dev python3-opengl python3-configobj libgtksourceview-3.0-dev tcl-tclreadline mesa-utils python3-serial python3-pip
Code:
sudo apt install - y libeditreadline-dev
Code:
sudo geany /etc/lightdm/lightdm.conf

scroll down to line ~ 126 and remove the # + add your user name from:

    #autologin-user=
    #autologin-user-timeout=0


add to grub via grub customizer
Code:
quiet splash isolcpus=2,3 intel_idle.max_cstate=0 processor.max_cstate=0 acpi_irq_nobalance noirqbalance
Code:
latency-histogram --nobase --sbinsize 1000 --show

    uname -a
    Linux LinuxCNC 5.10.0-14-rt-amd64 #1 SMP PREEMPT_RT Debian 5.10.113-1 (2022-04-29) x86_64 GNU/Linux
Code:
git clone https://github.com/LinuxCNC/linuxcnc.git linuxcnc-dev cd linuxcnc-dev/debian ./configure uspace cd .. dpkg-buildpackage -b -uc install the uspace deb sudo dpkg -i <package>.deb



>>>>
Confirmed latency at this point sub 50uS + SDEV ~1.8uS
Run Axis Sim + Gmoccapy Sim
loaded without issue and jog etc.
>>>>

    QTPyVCP
Code:
    sudo apt install -y dh-python libudev-dev bwidget libeditreadline-dev asciidoc dblatex docbook-xsl dvipng ghostscript graphviz groff imagemagick inkscape python3-lxml source-highlight w3c-linkchecker texlive-latex-recommended asciidoc-dblatex python3-dev python3-tk libxmu-dev libglu1-mesa-dev libgl1-mesa-dev libgtk2.0-dev libgtk-3-dev gettext intltool autoconf libboost-python-dev libmodbus-dev libusb-1.0-0-dev psmisc yapps2 libepoxy-dev python3-xlib python3-pyqt5 python3-dbus.mainloop.pyqt5 python3-pyqt5.qtopengl python3-pyqt5.qsci python3-pyqt5.qtmultimedia python3-pyqt5.qtquick qml-module-qtquick-controls gstreamer1.0-plugins-bad  libqt5multimedia5-plugins pyqt5-dev-tools python3-dev python3-setuptools python3-wheel python3-yapps dpkg-dev python3-serial libtk-img qttools5-dev qttools5-dev-tools python3-wheel espeak espeak-data espeak-ng freeglut3 gdal-data gstreamer1.0-tools libaec0 libarmadillo10 libarpack2 libcfitsio9 libcharls2 libdap27 libdapclient6v5 libepsilon1 libespeak1 libfreexl1 libfyba0 libgdal28 libgdcm3.0 libgeos-3.9.0 libgeos-c1v5 libgeotiff5 libgif7 libglew2.1 libgtksourceview-3.0-dev libhdf4-0-alt libhdf5-103-1 libhdf5-hl-100 libimagequant0 libkmlbase1 libkmldom1 libkmlengine1 liblept5 libmariadb3 libminizip1 libnetcdf18 libodbc1 libogdi4.1 libopencv-calib3d4.5 libopencv-contrib4.5 libopencv-core4.5 libopencv-dnn4.5 libopencv-features2d4.5 libopencv-flann4.5 libopencv-highgui4.5 libopencv-imgcodecs4.5 libopencv-imgproc4.5 libopencv-ml4.5 libopencv-objdetect4.5 libopencv-photo4.5 libopencv-shape4.5 libopencv-stitching4.5 libopencv-video4.5 libopencv-videoio4.5 libportaudio2 libpq5 libproj19 libprotobuf23 libqhull8.0 librttopo1 libsocket++1 libspatialite7 libsuperlu5 libsz2 libtbb2 libtesseract4 liburiparser1 libxerces-c3.2 libxml2-dev mariadb-common mesa-utils mysql-common odbcinst odbcinst1debian2 proj-bin proj-data python3-configobj python3-espeak python3-gi-cairo python3-olefile python3-opencv python3-opengl python3-pil python3-pil.imagetk python3-pyqt5.qtsvg python3-pyqt5.qtwebkit tcl-tclreadline geotiff-bin gdal-bin glew-utils libgtksourceview-3.0-doc libhdf4-doc libhdf4-alt-dev hdf4-tools odbc-postgresql tdsodbc ogdi-bin python-configobj-doc libgle3 python-pil-doc python3-pil-dbg python3-pil.imagetk-dbg python3-sqlalchemy netcat     git clone https://github.com/kcjengr/qtpyvcp     cd qtpyvcp     python3 -m pip install --editable .     cp scripts/.xsessionrc ~/     Log out and log back in again.     qtpyvcp -h     qtpyvcp -i     cd ~/qtpyvcp/pyqt5designer/Qt5.15.2-64bit/python3.9/     sudo ./install.sh     cp -r ~/qtpyvcp/linuxcnc ~/

>>>
QTPyVCP Sims loaded and tested

>>>


    PROBE_BASIC
Code:
    git clone https://github.com/kcjengr/probe_basic -b python3 probe_basic     cd probe_basic     qcompile .     python3 -m pip install --editable .     cd     cp -r ~/probe_basic/probe_basic/fonts/ ~/.local/share/     cp -r ~/probe_basic/config/probe_basic/ ~/linuxcnc/configs/     python3 -m pip install git+https://github.com/kcjengr/qtpyvcp.conversational-gcode.git




 
 
Last edit: 4 years 5 months ago by robertspark.

Please Log in or Create an account to join the conversation.

More
4 years 5 months ago #243891 by billykid
Replied by billykid on topic Robertspark's CNC Setup
hi, i tried to install the image but i got some errors. sudo geany /etc/lightdm/lightdm.conf creates a new file for me because it doesn't exist ... qtpyvcp -h qtpyvcp -i these two commands also return an error and the last pip install git + https: //github.com/kcjengr/qtpyvcp.conversational-gcode.git now i had to stop next time i will try to be more precise however kernel preempt-rt is installed and qt too.

Please Log in or Create an account to join the conversation.

Time to create page: 0.071 seconds
Powered by Kunena Forum